@@ -1,57 +1,61 @@
 from __future__ import absolute_import
-
 import json
 import logging
 
 import requests
-
 from lexicon.providers.base import Provider as BaseProvider
 
-logger = logging.getLogger(__name__)
+
+LOGGER = logging.getLogger(__name__)
 
 NAMESERVER_DOMAINS = ['easydns.net']
 
+
 def ProviderParser(subparser):
-    subparser.add_argument("--auth-username", help="specify username for authentication")
-    subparser.add_argument("--auth-token", help="specify token for authentication")
+    subparser.add_argument(
+        "--auth-username", help="specify username for authentication")
+    subparser.add_argument(
+        "--auth-token", help="specify token for authentication")
 
 
 class Provider(BaseProvider):
 
-    def __init__(self, options, engine_overrides=None):
-        super(Provider, self).__init__(options, engine_overrides)
+    def __init__(self, config):
+        super(Provider, self).__init__(config)
         self.domain_id = None
-        self.api_endpoint = self.engine_overrides.get('api_endpoint', 'https://rest.easydns.net')
+        self.api_endpoint = self._get_provider_option(
+            'api_endpoint') or 'https://rest.easydns.net'
 
     def authenticate(self):
 
-        payload = self._get('/domain/{0}'.format(self.options['domain']))
+        payload = self._get('/domain/{0}'.format(self.domain))
 
         if payload['data']['exists'] == 'N':
             raise Exception('No domain found')
 
         self.domain_id = payload['data']['id']
 
-
     # Create record. If record already exists with the same content, do nothing'
+
     def create_record(self, type, name, content):
         record = {
             'type': type,
             'domain': self.domain_id,
             'host': self._relative_name(name),
-            'ttl': self.options['ttl'],
+            'ttl': self._get_lexicon_option('ttl'),
             'prio': 0,
             'rdata': content
         }
         payload = {}
         try:
-            payload = self._put('/zones/records/add/{0}/{1}'.format(self.domain_id, type), record)
+            payload = self._put(
+                '/zones/records/add/{0}/{1}'.format(self.domain_id, type), record)
         except requests.exceptions.HTTPError as e:
             if e.response.status_code == 400:
                 payload = {}
 
                 # http 400 is ok here, because the record probably already exists
-        logger.debug('create_record: %s', True)
+        LOGGER.debug('create_record: %s', True)
         return True
 
     # List all records. Return an empty list if no records found
@@ -75,18 +79,20 @@ class Provider(BaseProvider):
         if type:
             records = [record for record in records if record['type'] == type]
         if name:
-            records = [record for record in records if record['name'] == self._full_name(name)]
+            records = [record for record in records if record['name']
+                       == self._full_name(name)]
         if content:
-            records = [record for record in records if record['content'] == content]
+            records = [
+                record for record in records if record['content'] == content]
 
-        logger.debug('list_records: %s', records)
+        LOGGER.debug('list_records: %s', records)
         return records
 
     # Create or update a record.
     def update_record(self, identifier, type=None, name=None, content=None):
 
         data = {
-            'ttl': self.options['ttl']
+            'ttl': self._get_lexicon_option('ttl')
         }
         if type:
             data['type'] = type
@@ -97,7 +103,7 @@ class Provider(BaseProvider):
 
         payload = self._post('/zones/records/{0}'.format(identifier), data)
 
-        logger.debug('update_record: %s', True)
+        LOGGER.debug('update_record: %s', True)
         return True
 
     # Delete an existing record.
@@ -109,26 +115,27 @@ class Provider(BaseProvider):
             delete_record_id = [record['id'] for record in records]
         else:
             delete_record_id.append(identifier)
-        
-        logger.debug('delete_records: %s', delete_record_id)
+
+        LOGGER.debug('delete_records: %s', delete_record_id)
 
         for record_id in delete_record_id:
-            payload = self._delete('/zones/records/{0}/{1}'.format(self.domain_id, record_id))
+            payload = self._delete(
+                '/zones/records/{0}/{1}'.format(self.domain_id, record_id))
 
         # is always True at this point, if a non 200 response is returned an error is raised.
-        logger.debug('delete_record: %s', True)
+        LOGGER.debug('delete_record: %s', True)
         return True
 
-
     # Helpers
+
     def _request(self, action='GET',  url='/', data=None, query_params=None):
         if data is None:
             data = {}
         if query_params is None:
             query_params = {}
         query_params['format'] = 'json'
-        query_params['_user'] = self.options['auth_username']
-        query_params['_key'] = self.options['auth_token']
+        query_params['_user'] = self._get_provider_option('auth_username')
+        query_params['_key'] = self._get_provider_option('auth_token')
         default_headers = {
             'Accept': 'application/json',
             'Content-Type': 'application/json'
@@ -137,5 +144,6 @@ class Provider(BaseProvider):
         r = requests.request(action, self.api_endpoint + url, params=query_params,
                              data=json.dumps(data),
                              headers=default_headers)
-        r.raise_for_status()  # if the request fails for any reason, throw an error.
+        # if the request fails for any reason, throw an error.
+        r.raise_for_status()
         return r.json()
