@@ -1,20 +1,20 @@
 from __future__ import absolute_import
-
+import base64
+import copy
 import json
 import logging
 import re
-import base64
-import copy
 
 import requests
+from lexicon.providers.base import Provider as BaseProvider
 from requests.auth import HTTPBasicAuth
 
-from lexicon.providers.base import Provider as BaseProvider
 
-logger = logging.getLogger(__name__)
+LOGGER = logging.getLogger(__name__)
 
 NAMESERVER_DOMAINS = ['gehirn.jp']
 
+
 def ProviderParser(subparser):
     subparser.add_argument(
         "--auth-token", help="specify access token for authentication")
@@ -33,30 +33,29 @@ BUILD_FORMATS = {
 }
 
 FORMAT_RE = {
-    "A": re.compile("(?P<address>.+)"),
-    "AAAA": re.compile("(?P<address>.+)"),
-    "CNAME": re.compile("(?P<cname>.+)"),
-    "TXT": re.compile("(?P<data>.+)"),
-    "NS": re.compile("(?P<nsdname>.+)"),
-    "MX": re.compile("(?P<prio>\d+)\s+(?P<exchange>.+)"),
-    "SRV": re.compile("(?P<prio>\d+)\s+(?P<weight>\d+)\s+(?P<port>\d+)\s+(?P<target>.+)"),
+    "A": re.compile(r"(?P<address>.+)"),
+    "AAAA": re.compile(r"(?P<address>.+)"),
+    "CNAME": re.compile(r"(?P<cname>.+)"),
+    "TXT": re.compile(r"(?P<data>.+)"),
+    "NS": re.compile(r"(?P<nsdname>.+)"),
+    "MX": re.compile(r"(?P<prio>\d+)\s+(?P<exchange>.+)"),
+    "SRV": re.compile(r"(?P<prio>\d+)\s+(?P<weight>\d+)\s+(?P<port>\d+)\s+(?P<target>.+)"),
 }
 
 
 class Provider(BaseProvider):
 
-    def __init__(self, options, engine_overrides=None):
-        super(Provider, self).__init__(options, engine_overrides)
+    def __init__(self, config):
+        super(Provider, self).__init__(config)
         self.domain_id = None
         self.version_id = None
-        self.api_endpoint = self.engine_overrides.get(
-            'api_endpoint', 'https://api.gis.gehirn.jp/dns/v1')
+        self.api_endpoint = 'https://api.gis.gehirn.jp/dns/v1'
 
     def authenticate(self):
         payload = self._get('/zones')
 
         domains = [item for item in payload if item['name']
-                   == self.options['domain']]
+                   == self.domain]
         if not domains:
             raise Exception('No domain found')
 
@@ -75,19 +74,19 @@ class Provider(BaseProvider):
                 'type': type,
                 'name': name,
                 'enable_alias': False,
-                'ttl': self.options['ttl'],
+                'ttl': self._get_lexicon_option('ttl'),
                 'records': [],
             }
         else:
             record = records[0]
 
         if r in record["records"]:
-            logger.debug('create_record: %s', True)
+            LOGGER.debug('create_record: %s', True)
             return True
 
         record["records"].append(r)
         self._update_record(record)
-        logger.debug('create_record: %s', True)
+        LOGGER.debug('create_record: %s', True)
         return True
 
     # List all records. Return an empty list if no records found
@@ -115,7 +114,7 @@ class Provider(BaseProvider):
             records = [
                 record for record in records if record['content'] == content]
 
-        logger.debug('list_records: %s', records)
+        LOGGER.debug('list_records: %s', records)
         return records
 
     # Create or update a record.
@@ -134,7 +133,7 @@ class Provider(BaseProvider):
 
             if not records:
                 self.create_record(type=type, name=name, content=content)
-                logger.debug('update_record: %s', True)
+                LOGGER.debug('update_record: %s', True)
                 return True
 
             record = {
@@ -142,7 +141,7 @@ class Provider(BaseProvider):
                 'type': type,
                 'name': name,
                 'enable_alias': False,
-                'ttl': self.options['ttl'],
+                'ttl': self._get_lexicon_option('ttl'),
                 'records': [self._parse_content(type, content)],
             }
 
@@ -162,7 +161,7 @@ class Provider(BaseProvider):
                     name=name or record["name"],
                     content=content
                 )
-                logger.debug('update_record: %s', True)
+                LOGGER.debug('update_record: %s', True)
                 return True
             else:
                 # update entire record
@@ -170,13 +169,13 @@ class Provider(BaseProvider):
                     record["type"] = type
                 if name:
                     record["name"] = name
-                record["ttl"] = self.options['ttl']
+                record["ttl"] = self._get_lexicon_option('ttl')
                 if content:
                     record["records"] = [
                         self._parse_content(record["type"], content)]
 
         self._update_record(record)
-        logger.debug('update_record: %s', True)
+        LOGGER.debug('update_record: %s', True)
         return True
 
     # Delete an existing record.
@@ -189,7 +188,7 @@ class Provider(BaseProvider):
                     self.domain_id, self.version_id, identifier,
                 )
                 self._delete(path)
-                logger.debug('delete_record: %s', True)
+                LOGGER.debug('delete_record: %s', True)
                 return True
 
             record_identifier = identifier.split(".")[1]
@@ -215,7 +214,7 @@ class Provider(BaseProvider):
                 else:
                     self._update_record(record)
 
-                logger.debug('delete_record: %s', True)
+                LOGGER.debug('delete_record: %s', True)
                 return True
             else:
                 raise Exception('Record identifier could not be found.')
@@ -241,7 +240,7 @@ class Provider(BaseProvider):
             )
             self._delete(path)
 
-        logger.debug('delete_record: %s', True)
+        LOGGER.debug('delete_record: %s', True)
         return True
 
     # Helpers
@@ -307,7 +306,7 @@ class Provider(BaseProvider):
             'Content-Type': 'application/json',
         }
         default_auth = HTTPBasicAuth(
-            self.options['auth_token'], self.options['auth_secret'])
+            self._get_provider_option('auth_token'), self._get_provider_option('auth_secret'))
 
         query_string = ""
         if query_params:
@@ -321,6 +320,6 @@ class Provider(BaseProvider):
             # if the request fails for any reason, throw an error.
             r.raise_for_status()
         except:
-            logger.error(r.text)
+            LOGGER.error(r.text)
             raise
         return r.json()
