@@ -1,34 +1,36 @@
 from __future__ import absolute_import
-
 import json
 import logging
 
 import requests
-
 from lexicon.providers.base import Provider as BaseProvider
 
-logger = logging.getLogger(__name__)
+
+LOGGER = logging.getLogger(__name__)
 
 NAMESERVER_DOMAINS = ['online.net']
 
+
 def ProviderParser(subparser):
     subparser.add_argument("--auth-token", help="specify private api token")
 
+
 def to_data(type, content):
     if type == "TXT":
         return '"{0}"'.format(content)
     else:
         return content
 
+
 class Provider(BaseProvider):
 
-    def __init__(self, options, engine_overrides=None):
-        super(Provider, self).__init__(options, engine_overrides)
+    def __init__(self, config):
+        super(Provider, self).__init__(config)
         self.zone_name = 'Zone Automatic Lexicon '
         self.passive_zone = None
         self.active_zone = None
-        self.domain_id = self.options['domain']
-        self.api_endpoint = self.engine_overrides.get('api_endpoint', 'https://api.online.net/api/v1')
+        self.domain_id = self.domain
+        self.api_endpoint = 'https://api.online.net/api/v1'
 
     def authenticate(self):
         self.init_zones()
@@ -57,7 +59,6 @@ class Provider(BaseProvider):
         self.passive_zone = passive_row['uuid_ref']
         self.update_passive_zone()
 
-
     def update_passive_zone(self):
         self._put(
             '/domain/{0}/version/{1}/zone_from_bind'.format(
@@ -69,7 +70,7 @@ class Provider(BaseProvider):
 
     def get_bind_zone(self):
         records = self.list_zone_records(self.active_zone)
-         # then convert records to bind format
+        # then convert records to bind format
         bindStr = ''
         for record in records:
             bindStr = bindStr + '{0} {1} IN {2} {3}{4}\n'.format(
@@ -93,8 +94,8 @@ class Provider(BaseProvider):
         self.active_zone = zone
         self.update_passive_zone()
 
-
     # Create record. If record already exists with the same content, do nothing'
+
     def create_record(self, type, name, content):
         try:
             record = self.find_record(type, name, content)
@@ -105,8 +106,8 @@ class Provider(BaseProvider):
                 'name': self._fqdn_name(name),
                 'type': type,
                 'data': to_data(type, content),
-                'priority': self.options['priority'] or '',
-                'ttl': self.options['ttl'] or ''
+                'priority': self._get_lexicon_option('priority') or '',
+                'ttl': self._get_lexicon_option('ttl') or ''
             }
 
             payload = self._post(
@@ -117,11 +118,11 @@ class Provider(BaseProvider):
                 record
             )
         except Exception as e:
-            logger.debug(e)
+            LOGGER.debug(e)
             return False
 
         self.enable_zone()
-        logger.debug('create_record: %s', True)
+        LOGGER.debug('create_record: %s', True)
         return True
 
     def find_zone_records(self, zone, type=None, name=None, content=None):
@@ -141,11 +142,13 @@ class Provider(BaseProvider):
             records = [record for record in records if record['type'] == type]
         if name:
             fullName = self._full_name(name)
-            records = [record for record in records if record['name'] == fullName]
+            records = [
+                record for record in records if record['name'] == fullName]
         if content:
-            records = [record for record in records if record['content'] == content]
+            records = [
+                record for record in records if record['content'] == content]
 
-        logger.debug('list_records: %s', records)
+        LOGGER.debug('list_records: %s', records)
         return records
 
     def list_zone_records(self, zone_id):
@@ -162,12 +165,13 @@ class Provider(BaseProvider):
         else:
             return records[0]
 
-
     # Create or update a record.
+
     def update_record(self, id, type=None, name=None, content=None):
         record = self.find_record(type, name)
         if record is None:
-            logger.debug("cannot find record to update: %s %s %s", id, type, name)
+            LOGGER.debug("cannot find record to update: %s %s %s",
+                         id, type, name)
             return True
         if type:
             record['type'] = type
@@ -175,11 +179,11 @@ class Provider(BaseProvider):
             record['name'] = self._fqdn_name(name)
         if content:
             record['data'] = to_data(type, content)
-        if self.options.get('ttl'):
-            record['ttl'] = self.options.get('ttl')
+        if self._get_lexicon_option('ttl'):
+            record['ttl'] = self._get_lexicon_option('ttl')
         # it is weird that 'aux' becomes 'priority' in online's api
-        if self.options['priority']:
-            record['priority'] = self.options['priority']
+        if self._get_lexicon_option('priority'):
+            record['priority'] = self._get_lexicon_option('priority')
 
         if id is None:
             id = record['id']
@@ -194,12 +198,12 @@ class Provider(BaseProvider):
             ), record)
 
         except Exception as e:
-            logger.debug(e)
+            LOGGER.debug(e)
             return False
 
         self.enable_zone()
         # If it didn't raise from the http status code, then we're good
-        logger.debug('update_record: %s', id)
+        LOGGER.debug('update_record: %s', id)
         return True
 
     # Delete an existing record.
@@ -207,9 +211,9 @@ class Provider(BaseProvider):
     def delete_record(self, id=None, type=None, name=None, content=None):
         records = self.list_records(type, name, content)
         if len(records) == 0:
-            logger.debug("Cannot find records %s %s %s", type, name, content)
+            LOGGER.debug("Cannot find records %s %s %s", type, name, content)
             return False
-        logger.debug('delete_records: %s records found', len(records))
+        LOGGER.debug('delete_records: %s records found', len(records))
         try:
             for record in records:
                 payload = self._delete('/domain/{0}/version/{1}/zone/{2}'.format(
@@ -218,12 +222,12 @@ class Provider(BaseProvider):
                     record['id']
                 ))
         except Exception as e:
-            logger.debug(e)
+            LOGGER.debug(e)
             return False
 
         self.enable_zone()
         # is always True at this point, if a non 200 response is returned an error is raised.
-        logger.debug('delete_record: %s', True)
+        LOGGER.debug('delete_record: %s', True)
         return True
 
     def _patch(self, url='/', data=None, query_params=None):
@@ -236,13 +240,13 @@ class Provider(BaseProvider):
 
         headers = {
             'Accept': 'application/json',
-            'Authorization': 'Bearer {0}'.format(self.options['auth_token'])
+            'Authorization': 'Bearer {0}'.format(self._get_provider_option('auth_token'))
         }
         if data is not None:
             if type(data) is str:
-                headers['Content-Type'] = 'text/plain';
+                headers['Content-Type'] = 'text/plain'
             else:
-                headers['Content-Type'] = 'application/json';
+                headers['Content-Type'] = 'application/json'
                 data = json.dumps(data)
 
         r = requests.request(
@@ -252,6 +256,7 @@ class Provider(BaseProvider):
             data=data,
             headers=headers
         )
-        r.raise_for_status()  # if the request fails for any reason, throw an error.
+        # if the request fails for any reason, throw an error.
+        r.raise_for_status()
 
         return r.text and r.json() or ''
