@@ -1,30 +1,33 @@
 from __future__ import absolute_import
-
 import json
 import logging
 
 import requests
-
 from lexicon.providers.base import Provider as BaseProvider
 
-logger = logging.getLogger(__name__)
+
+LOGGER = logging.getLogger(__name__)
 
 NAMESERVER_DOMAINS = ['rage4.com']
 
+
 def ProviderParser(subparser):
-    subparser.add_argument("--auth-username", help="specify email address for authentication")
-    subparser.add_argument("--auth-token", help="specify token for authentication")
+    subparser.add_argument(
+        "--auth-username", help="specify email address for authentication")
+    subparser.add_argument(
+        "--auth-token", help="specify token for authentication")
+
 
 class Provider(BaseProvider):
 
-    def __init__(self, options, engine_overrides=None):
-        super(Provider, self).__init__(options, engine_overrides)
+    def __init__(self, config):
+        super(Provider, self).__init__(config)
         self.domain_id = None
-        self.api_endpoint = self.engine_overrides.get('api_endpoint', 'https://rage4.com/rapi')
+        self.api_endpoint = 'https://rage4.com/rapi'
 
     def authenticate(self):
 
-        payload = self._get('/getdomainbyname/', {'name': self.options['domain']})
+        payload = self._get('/getdomainbyname/', {'name': self.domain})
 
         if not payload['id']:
             raise Exception('No domain found')
@@ -44,18 +47,18 @@ class Provider(BaseProvider):
             'content': content,
             'type': type
         }
-        if self.options.get('ttl'):
-            record['ttl'] = self.options.get('ttl')
+        if self._get_lexicon_option('ttl'):
+            record['ttl'] = self._get_lexicon_option('ttl')
 
         payload = {}
         try:
-            payload = self._post('/createrecord/',{},record)
+            payload = self._post('/createrecord/', {}, record)
         except requests.exceptions.HTTPError as e:
             if e.response.status_code == 400:
                 payload = {}
 
                 # http 400 is ok here, because the record probably already exists
-        logger.debug('create_record: %s', payload['status'])
+        LOGGER.debug('create_record: %s', payload['status'])
         return payload['status']
 
     # List all records. Return an empty list if no records found
@@ -83,9 +86,10 @@ class Provider(BaseProvider):
         if type:
             records = [record for record in records if record['type'] == type]
         if content:
-            records = [record for record in records if record['content'] == content]
+            records = [
+                record for record in records if record['content'] == content]
 
-        logger.debug('list_records: %s', records)
+        LOGGER.debug('list_records: %s', records)
         return records
 
     # Create or update a record.
@@ -99,14 +103,14 @@ class Provider(BaseProvider):
             data['name'] = self._full_name(name)
         if content:
             data['content'] = content
-        if self.options.get('ttl'):
-            data['ttl'] = self.options.get('ttl')
+        if self._get_lexicon_option('ttl'):
+            data['ttl'] = self._get_lexicon_option('ttl')
         # if type:
         #     raise 'Type updating is not supported by this provider.'
 
         payload = self._put('/updaterecord/', {}, data)
 
-        logger.debug('update_record: %s', payload['status'])
+        LOGGER.debug('update_record: %s', payload['status'])
         return payload['status']
 
     # Delete an existing record.
@@ -118,18 +122,18 @@ class Provider(BaseProvider):
             delete_record_id = [record['id'] for record in records]
         else:
             delete_record_id.append(identifier)
-        
-        logger.debug('delete_records: %s', delete_record_id)
+
+        LOGGER.debug('delete_records: %s', delete_record_id)
 
         for record_id in delete_record_id:
             payload = self._post('/deleterecord/', {'id': record_id})
 
         # is always True at this point, if a non 200 response is returned an error is raised.
-        logger.debug('delete_record: %s', True)
+        LOGGER.debug('delete_record: %s', True)
         return True
 
-
     # Helpers
+
     def _request(self, action='GET',  url='/', data=None, query_params=None):
         if data is None:
             data = {}
@@ -140,11 +144,13 @@ class Provider(BaseProvider):
             'Accept': 'application/json',
             'Content-Type': 'application/json',
         }
-        default_auth = requests.auth.HTTPBasicAuth(self.options['auth_username'], self.options['auth_token'])
+        default_auth = requests.auth.HTTPBasicAuth(self._get_provider_option(
+            'auth_username'), self._get_provider_option('auth_token'))
 
         r = requests.request(action, self.api_endpoint + url, params=query_params,
                              data=json.dumps(data),
                              headers=default_headers,
                              auth=default_auth)
-        r.raise_for_status()  # if the request fails for any reason, throw an error.
+        # if the request fails for any reason, throw an error.
+        r.raise_for_status()
         return r.json()
