@@ -1,45 +1,49 @@
 from __future__ import absolute_import
-
 import json
 import logging
 
 import requests
-
 from lexicon.providers.base import Provider as BaseProvider
 
+
 __author__ = 'Aliaksandr Kharkevich'
 __license__ = 'MIT'
 __contact__ = 'https://github.com/kharkevich'
 
-logger = logging.getLogger(__name__)
+LOGGER = logging.getLogger(__name__)
 
 NAMESERVER_DOMAINS = ['yandex.com']
 
+
 def ProviderParser(subparser):
-    subparser.add_argument("--auth-token", help="specify PDD token (https://tech.yandex.com/domain/doc/concepts/access-docpage/)")
+    subparser.add_argument(
+        "--auth-token", help="specify PDD token (https://tech.yandex.com/domain/doc/concepts/access-docpage/)")
+
 
 class Provider(BaseProvider):
 
-    def __init__(self, options, engine_overrides=None):
-        super(Provider, self).__init__(options, engine_overrides)
+    def __init__(self, config):
+        super(Provider, self).__init__(config)
         self.domain_id = None
-        self.api_endpoint = self.engine_overrides.get('api_endpoint', 'https://pddimp.yandex.ru/api2/admin/dns')
+        self.api_endpoint = 'https://pddimp.yandex.ru/api2/admin/dns'
 
     def authenticate(self):
-        payload = self._get('/list?domain={0}'.format(self.options['domain']))
+        payload = self._get('/list?domain={0}'.format(self.domain))
         if payload['success'] != "ok":
             raise Exception('No domain found')
-        self.domain_id = self.options['domain']
+        self.domain_id = self.domain
 
     def create_record(self, type, name, content):
         if (type == 'CNAME') or (type == 'MX') or (type == 'NS'):
-            content = content.rstrip('.') + '.' # make sure a the data is always a FQDN for CNAMe.
+            # make sure a the data is always a FQDN for CNAMe.
+            content = content.rstrip('.') + '.'
 
-        querystring = 'domain={0}&type={1}&subdomain={2}&content={3}'.format(self.domain_id, type, self._relative_name(name), content)
-        if self.options.get('ttl'):
-            querystring += "&ttl={0}".format(self.options.get('ttl'))
+        querystring = 'domain={0}&type={1}&subdomain={2}&content={3}'.format(
+            self.domain_id, type, self._relative_name(name), content)
+        if self._get_lexicon_option('ttl'):
+            querystring += "&ttl={0}".format(self._get_lexicon_option('ttl'))
 
-        payload = self._post('/add', {},querystring)
+        payload = self._post('/add', {}, querystring)
 
         return self._check_exitcode(payload, 'create_record')
 
@@ -74,20 +78,23 @@ class Provider(BaseProvider):
         if type:
             records = [record for record in records if record['type'] == type]
         if name:
-            records = [record for record in records if record['name'] == self._full_name(name)]
+            records = [record for record in records if record['name']
+                       == self._full_name(name)]
         if content:
-            records = [record for record in records if record['content'].lower() == content.lower()]
+            records = [
+                record for record in records if record['content'].lower() == content.lower()]
 
-        logger.debug('list_records: %s', records)
+        LOGGER.debug('list_records: %s', records)
         return records
 
     # Just update existing record. Domain ID (domain) and Identifier (record_id) is mandatory
     def update_record(self, identifier, type=None, name=None, content=None):
 
         if not identifier:
-            logger.debug('Domain ID (domain) and Identifier (record_id) is mandatory parameters for this case')
+            LOGGER.debug(
+                'Domain ID (domain) and Identifier (record_id) is mandatory parameters for this case')
             return False
-        
+
         data = ''
         if type:
             data += '&type={0}'.format(type)
@@ -96,7 +103,8 @@ class Provider(BaseProvider):
         if content:
             data += '&content={0}'.format(content)
 
-        payload = self._post('/edit', {}, 'domain={0}&record_id={1}'.format(self.domain_id, identifier) + data)
+        payload = self._post(
+            '/edit', {}, 'domain={0}&record_id={1}'.format(self.domain_id, identifier) + data)
 
         return self._check_exitcode(payload, 'update_record')
 
@@ -109,13 +117,14 @@ class Provider(BaseProvider):
             delete_record_id = [record['id'] for record in records]
         else:
             delete_record_id.append(identifier)
-        
-        logger.debug('delete_records: %s', delete_record_id)
-        
-        for record_id in delete_record_id:
-            payload = self._post('/del', {}, 'domain={0}&record_id={1}'.format(self.domain_id, record_id))
 
-        #return self._check_exitcode(payload, 'delete_record')
+        LOGGER.debug('delete_records: %s', delete_record_id)
+
+        for record_id in delete_record_id:
+            payload = self._post(
+                '/del', {}, 'domain={0}&record_id={1}'.format(self.domain_id, record_id))
+
+        # return self._check_exitcode(payload, 'delete_record')
         return True
 
     # Helpers
@@ -127,7 +136,7 @@ class Provider(BaseProvider):
         default_headers = {
             'Accept': 'application/json',
             'Content-Type': 'application/json',
-            'PddToken': self.options.get('auth_token')
+            'PddToken': self._get_provider_option('auth_token')
         }
 
         if not url.startswith(self.api_endpoint):
@@ -136,7 +145,8 @@ class Provider(BaseProvider):
         r = requests.request(action, url, params=query_params,
                              data=json.dumps(data),
                              headers=default_headers)
-        r.raise_for_status()  # if the request fails for any reason, throw an error.
+        # if the request fails for any reason, throw an error.
+        r.raise_for_status()
         if action == 'DELETE':
             return ''
         else:
@@ -144,11 +154,11 @@ class Provider(BaseProvider):
 
     def _check_exitcode(self, payload, title):
         if payload['success'] == 'ok':
-            logger.debug('%s: %s', title, payload['success'])
+            LOGGER.debug('%s: %s', title, payload['success'])
             return True
         elif payload['error'] == 'record_exists':
-            logger.debug('%s: %s', title, True)
+            LOGGER.debug('%s: %s', title, True)
             return True
         else:
-            logger.debug('%s: %s', title, payload['error'])
+            LOGGER.debug('%s: %s', title, payload['error'])
             return False
