@@ -1,6 +1,8 @@
 from unittest import TestCase
-from lexicon.providers.onapp import Provider
+
 from integration_tests import IntegrationTests
+from lexicon.providers.onapp import Provider
+
 
 class OnappProviderTests(TestCase, IntegrationTests):
 
@@ -11,7 +13,5 @@ class OnappProviderTests(TestCase, IntegrationTests):
     def _filter_headers(self):
         return ['Authorization']
 
-    def _test_options(self):
-        options = super(OnappProviderTests, self)._test_options()
-        options.update({'auth_server':'https://dashboard.dynomesh.com.au'})
-        return options
+    def _test_parameters_overrides(self):
+        return {'auth_server': 'https://dashboard.dynomesh.com.au'}
