@@ -1,7 +1,8 @@
-from lexicon.providers.powerdns import Provider
-from integration_tests import IntegrationTests
 from unittest import TestCase
+
 import pytest
+from integration_tests import IntegrationTests
+from lexicon.providers.powerdns import Provider
 
 
 # Hook into testing framework by inheriting unittest.TestCase and reuse
@@ -16,10 +17,8 @@ class PowerdnsProviderTests(TestCase, IntegrationTests):
     def _filter_headers(self):
         return ['X-API-Key']
 
-    def _test_options(self):
-        options = super(PowerdnsProviderTests, self)._test_options()
-        options.update({'pdns_server': 'https://dnsadmin.hhome.me', 'pdns_server_id': 'localhost'})
-        return options
+    def _test_parameters_overrides(self):
+        return {'pdns_server': 'https://dnsadmin.hhome.me', 'pdns_server_id': 'localhost'}
 
     # TODO: the following skipped suite and fixtures should be enabled
     @pytest.mark.skip(reason="new test, missing recording")
@@ -30,4 +29,3 @@ class PowerdnsProviderTests(TestCase, IntegrationTests):
     def skip_suite(self, request):
         if request.node.get_marker('ext_suite_1'):
             pytest.skip('Skipping extended suite')
-
