@@ -1,10 +1,12 @@
 # Test for one implementation of the interface
-from lexicon.providers.transip import Provider
-from integration_tests import IntegrationTests, provider_vcr
-from unittest import TestCase
-import pytest
-from tempfile import mkstemp
 import os
+from tempfile import mkstemp
+from unittest import TestCase
+
+import pytest
+from integration_tests import IntegrationTests, provider_vcr
+from lexicon.providers.transip import Provider
+
 
 FAKE_KEY = b"""
 -----BEGIN RSA PRIVATE KEY-----
@@ -57,22 +59,26 @@ class TransipProviderTests(TestCase, IntegrationTests):
     # Disable setUp and tearDown, and set a real username and key in
     # provider_opts to execute real calls
 
-    def _test_options(self):
-        options = super(TransipProviderTests, self)._test_options()
+    def _test_parameters_overrides(self):
         (_fake_fd, _fake_key) = mkstemp()
         _fake_file = os.fdopen(_fake_fd, 'wb', 1024)
         _fake_file.write(FAKE_KEY)
         _fake_file.close()
         self._fake_key = _fake_key
 
-        options.update({
+        options = {
             'auth_username': 'foo',
             'auth_api_key': _fake_key
-        })
+        }
+
         return options
 
     def tearDown(self):
-        os.unlink(self._fake_key)
+        try:
+            os.unlink(self._fake_key)
+        except AttributeError:
+            # Method _test_options may not have been executed, in this case self._fake_key does not exist.
+            pass
 
     def _filter_headers(self):
         return ['Cookie']
